==> chromium-8.0.552.40.tar.bz2: chromium-8.0.552.40/chrome/installer/util/master_preferences_constants.cc <==
// Copyright (c) 2010 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#include "chrome/installer/util/master_preferences_constants.h"

namespace installer_util {
namespace master_preferences {
  const char kAltFirstRunBubble[] = "oem_bubble";
  const char kAltShortcutText[] = "alternate_shortcut_text";
  const char kChromeFrame[] = "chrome_frame";
  const char kChromeShortcutIconIndex[] = "chrome_shortcut_icon_index";
  const char kCreateAllShortcuts[] = "create_all_shortcuts";
  const char kDistroImportBookmarksPref[] = "import_bookmarks";
  const char kDistroImportBookmarksFromFilePref[] =
      "import_bookmarks_from_file";
  const char kDistroImportHistoryPref[] = "import_history";
  const char kDistroImportHomePagePref[] = "import_home_page";
  const char kDistroImportSearchPref[] = "import_search_engine";
  const char kDistroPingDelay[] = "ping_delay";
  const char kDistroShowWelcomePage[] = "show_welcome_page";
  const char kDistroSkipFirstRunPref[] = "skip_first_run_ui";
  const char kDistroSuppressFirstRunBubble[] = "suppress_first_run_bubble";
  const char kDoNotCreateShortcuts[] = "do_not_create_shortcuts";
  const char kDoNotLaunchChrome[] = "do_not_launch_chrome";
  const char kDoNotRegisterForUpdateLaunch[] =
      "do_not_register_for_update_launch";
  const char kMakeChromeDefault[] = "make_chrome_default";
  const char kMakeChromeDefaultForUser[] = "make_chrome_default_for_user";
  const char kMsi[] = "msi";
  const char kRequireEula[] = "require_eula";
  const char kSearchEngineExperimentPref[] = "search_engine_experiment";
  const char kSearchEngineExperimentRandomizePref[] =
      "search_engine_experiment_randomize";
  const char kSystemLevel[] = "system_level";
  const char kVerboseLogging[] = "verbose_logging";
  const char kExtensionsBlock[] = "extensions.settings";
}  // namespace master_preferences
}  // namespace installer_util

==> chromium-18.0.1025.54.tar.bz2: chromium-18.0.1025.54/chrome/installer/util/master_preferences_constants.cc <==
// Copyright (c) 2012 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#include "chrome/installer/util/master_preferences_constants.h"

namespace installer {
namespace master_preferences {
  const char kAltShortcutText[] = "alternate_shortcut_text";
  const char kAutoLaunchChrome[] = "auto_launch_chrome";
  const char kChrome[] = "chrome";
  const char kChromeFrame[] = "chrome_frame";
  const char kChromeFrameReadyMode[] = "ready_mode";
  const char kChromeShortcutIconIndex[] = "chrome_shortcut_icon_index";
  const char kCreateAllShortcuts[] = "create_all_shortcuts";
  const char kDisableLogging[] = "disable_logging";
  const char kDistroImportBookmarksPref[] = "import_bookmarks";
  const char kDistroImportBookmarksFromFilePref[] =
      "import_bookmarks_from_file";
  const char kDistroImportHistoryPref[] = "import_history";
  const char kDistroImportHomePagePref[] = "import_home_page";
  const char kDistroImportSearchPref[] = "import_search_engine";
  const char kDistroPingDelay[] = "ping_delay";
  const char kDistroShowWelcomePage[] = "show_welcome_page";
  const char kDistroSkipFirstRunPref[] = "skip_first_run_ui";
  const char kDistroSuppressFirstRunBubble[] = "suppress_first_run_bubble";
  const char kDoNotCreateShortcuts[] = "do_not_create_shortcuts";
  const char kDoNotLaunchChrome[] = "do_not_launch_chrome";
  const char kDoNotRegisterForUpdateLaunch[] =
      "do_not_register_for_update_launch";
  const char kLogFile[] = "log_file";
  const char kMakeChromeDefault[] = "make_chrome_default";
  const char kMakeChromeDefaultForUser[] = "make_chrome_default_for_user";
  const char kMsi[] = "msi";
  const char kMultiInstall[] = "multi_install";
  const char kRequireEula[] = "require_eula";
  const char kSystemLevel[] = "system_level";
  const char kVerboseLogging[] = "verbose_logging";
  const char kExtensionsBlock[] = "extensions.settings";
}  // namespace master_preferences
}  // namespace installer
